using System.Reflection;
using SampleProject.Reporting.Helper;
using SampleProject.Reporting.PrintObjects;
using Stimulsoft.Report;
using Stimulsoft.Report.Export;

public class Program
{
    private const string _exportPath = "D:/exportFile.pdf";

    public static void Main(string[] args)
    {
        var reportPageHelper = new ReportPageHelper();
        var indexList = new List<IndexDataObject>();
        indexList.Add(new IndexDataObject("Chapter 1", "1", true, "1"));
        indexList.Add(new IndexDataObject("Subchapter 1", "2", false, "1.1"));
        indexList.Add(new IndexDataObject("Chapter 2", "4", true, "2"));
        indexList.Add(new IndexDataObject("Subchapter 2", "5", false, "2.1"));
        indexList.Add(new IndexDataObject("Subchapter 3", "6", false, "2.2"));
        indexList.Add(new IndexDataObject("Subchapter 4", "", false, "2.3"));

        var indexPrintObject = new IndexDataPrintObject(indexList);

        var templatePath = Path.Combine(Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location), @"Reporting\Templates\IndexData.dll");
        StiReport.GetReportFromAssembly(templatePath);
        var report = new StiReport();
        report.RegBusinessObject("IndexData", "IndexData", indexPrintObject);
        report.Dictionary.SynchronizeBusinessObjects(5);
        report.Render(false);

        reportPageHelper.SetReportFonts(report);


        var pdfSettings = new StiPdfExportSettings
        {
            ImageQuality = 1.0f,
            ImageResolutionMode = StiImageResolutionMode.Auto,
            ImageResolution = 250
        };
        StiOptions.Export.Pdf.AllowImportSystemLibraries = true;
        report.ExportDocument(StiExportFormat.Pdf, _exportPath, pdfSettings);
    }
}